==> mobile_pos-1.0.0.tar.gz: lib/src/views/card_payment/card_success_page_new.dart <==
import 'package:audioplayers/audioplayers.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/success_response.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/widget/bankbox_confetti.dart';
import 'package:mobile_pos/src/views/card_payment/widget/share_receipt_sheet.dart';
import 'package:mobile_pos/src/views/card_payment/widget/success_card_icon.dart';
import 'package:mobile_pos/src/views/card_payment/widget/success_item_widget.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class CardSuccessPageNew extends StatefulWidget {
  final BankBoxResponse response;
  final double amount;
  final String? rrn;
  final String stan;
  final String cardNumber;
  final String terminalSerial;
  final String cardExpiry;
  const CardSuccessPageNew(
      {super.key,
      required this.amount,
      required this.rrn,
      required this.cardExpiry,
      required this.cardNumber,
      required this.terminalSerial,
      required this.stan,
      required this.response});

  @override
  State<CardSuccessPageNew> createState() => _CardSuccessPageNewState();
}

class _CardSuccessPageNewState extends State<CardSuccessPageNew> {
  @override
  void initState() {
    if (pluginConfig.enableSuccessSound ?? true) {
      rootBundle
          .load("packages/mobile_pos/assets/audio/success.wav")
          .then((value) {
        Uint8List audioUint8List =
            value.buffer.asUint8List(value.offsetInBytes, value.lengthInBytes);
        final player = AudioPlayer();
        player.play(BytesSource(audioUint8List));
      });
      super.initState();
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return PopScope(
        canPop: false,
        child: RavenPayScaffold(
            backgroundColor:
                pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
            bottomNavigationBar: Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
              child: Column(mainAxisSize: MainAxisSize.min, children: [
                Row(
                  children: [
                    Expanded(
                        child: RavenPayButton(
                      onPressed: () {
                        showRavenPayBottomSheet(context,
                            child: ShareReceiptSheet(rrn: widget.rrn ?? ""));
                      },
                      height: 48,
                      fontSize: 14,
                      fontWeight: FontWeight.w600,
                      textColor: pluginTheme.onPrimary,
                      buttonText: "Share Receipt",
                      buttonColor: pluginTheme.primaryColor,
                    )),
                    const Gap(16),
                    GestureDetector(
                      onTap: () {
                        toRavenPayHome(context);
                      },
                      child: Container(
                          height: 50,
                          width: 58,
                          padding: const EdgeInsets.all(14),
                          decoration: BoxDecoration(
                              color: pluginTheme.primaryColor.withOpacity(0.1),
                              borderRadius: BorderRadius.circular(8)),
                          child: Image.asset(loadAsset("cancel_icon.png"),
                              color: pluginTheme.primaryColor)),
                    )
                  ],
                ),
                const BottomNavSpacer()
              ]),
            ),
            body: SafeArea(
              child: Padding(
                padding:
                    EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
                child: Column(
                  children: [
                    const Gap(24),
                    Align(
                      alignment: Alignment.centerLeft,
                      child: GestureDetector(
                        onTap: () {
                          toRavenPayHome(context);
                        },
                        child:
                            const RoundedItemContainer(asset: "close_icon.png"),
                      ),
                    ),
                    Expanded(
                      child: SingleChildScrollView(
                        child: Stack(
                          children: [
                            Column(
                              children: [
                                Gap(size.height * 0.04),
                                Image.asset(loadAsset("success_icon.png"),
                                    width: size.width * 0.24),
                                const Gap(24),
                                Text("You have successfully paid",
                                    style: subtitle.copyWith(
                                        fontSize: 14,
                                        color: AppColors.ravenPayGrey,
                                        fontWeight: FontWeight.w400)),
                                const Gap(2),
                                RavenPayMoneyWidget(
                                  formatForm: "#,##0.00",
                                  amount: widget.amount.toString(),
                                  fontSize: 28,
                                  color: pluginTheme.isLightTheme
                                      ? AppColors.darkGrey
                                      : Colors.white,
                                ),
                                const Gap(32),
                                Container(
                                    padding: const EdgeInsets.symmetric(
                                        vertical: 16),
                                    width: double.infinity,
                                    decoration: BoxDecoration(
                                        color: pluginTheme.getFGColor,
                                        boxShadow: const [
                                          BoxShadow(
                                              color: Colors.grey,
                                              spreadRadius: -2,
                                              blurRadius: 2)
                                        ],
                                        borderRadius:
                                            BorderRadius.circular(16)),
                                    child: Column(
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: [
                                        Padding(
                                          padding: const EdgeInsets.symmetric(
                                              horizontal: 16),
                                          child: Row(
                                            children: [
                                              const SuccessCardIcon(),
                                              const Gap(12),
                                              Column(
                                                crossAxisAlignment:
                                                    CrossAxisAlignment.start,
                                                children: [
                                                  Text("Card Pan",
                                                      style: subtitle.copyWith(
                                                          fontWeight:
                                                              FontWeight.w400)),
                                                  const Gap(4),
                                                  Text(
                                                      formatCardPan(
                                                          widget.cardNumber),
                                                      style: subtitle.copyWith(
                                                          color: pluginTheme
                                                                  .isLightTheme
                                                              ? AppColors
                                                                  .ravenPayDark
                                                              : Colors.white))
                                                ],
                                              )
                                            ],
                                          ),
                                        ),
                                        const Gap(4),
                                        Divider(
                                          thickness: 1,
                                          color: pluginTheme.isLightTheme
                                              ? AppColors.lightModeBorder
                                              : AppColors.darkModeBorder,
                                        ),
                                        Padding(
                                            padding: const EdgeInsets.symmetric(
                                                horizontal: 16),
                                            child: Column(
                                              children: [
                                                SuccessItemWidget(
                                                    title: "Terminal SN",
                                                    value:
                                                        widget.terminalSerial),
                                                SuccessItemWidget(
                                                    title: "RRN",
                                                    value: widget.rrn ?? ""),
                                                SuccessItemWidget(
                                                  title: "Card Expiry",
                                                  value: formatExpiry(
                                                      widget.cardExpiry),
                                                ),
                                                SuccessItemWidget(
                                                    title: "Stan",
                                                    showDivider: false,
                                                    value: widget.stan)
                                              ],
                                            ))
                                      ],
                                    )),
                                const Gap(12),
                              ],
                            ),
                            BankBoxCoffetti(
                              key: UniqueKey(),
                            )
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            )));
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/card_payment/card_success_page_new.dart <==
import 'package:audioplayers/audioplayers.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/success_response.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/card_payment/widget/bankbox_confetti.dart';
import 'package:mobile_pos/src/views/card_payment/widget/share_receipt_sheet.dart';
import 'package:mobile_pos/src/views/card_payment/widget/success_card_icon.dart';
import 'package:mobile_pos/src/views/card_payment/widget/success_item_widget.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class CardSuccessPageNew extends StatefulWidget {
  final BankBoxResponse response;
  final double amount;
  final String? rrn;
  final String stan;
  final String cardNumber;
  final String terminalSerial;
  final String cardExpiry;
  const CardSuccessPageNew(
      {super.key,
      required this.amount,
      required this.rrn,
      required this.cardExpiry,
      required this.cardNumber,
      required this.terminalSerial,
      required this.stan,
      required this.response});

  @override
  State<CardSuccessPageNew> createState() => _CardSuccessPageNewState();
}

class _CardSuccessPageNewState extends State<CardSuccessPageNew> {
  @override
  void initState() {
    if (pluginConfig.enableSuccessSound ?? true) {
      rootBundle
          .load("packages/mobile_pos/assets/audio/success.wav")
          .then((value) {
        Uint8List audioUint8List =
            value.buffer.asUint8List(value.offsetInBytes, value.lengthInBytes);
        final player = AudioPlayer();
        player.play(BytesSource(audioUint8List));
      });
      super.initState();
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return PopScope(
        canPop: false,
        child: RavenPayScaffold(
            backgroundColor:
                pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
            bottomNavigationBar: Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
              child: Column(mainAxisSize: MainAxisSize.min, children: [
                Row(
                  children: [
                    Expanded(
                        child: RavenPayButton(
                      onPressed: () {
                        showRavenPayBottomSheet(context,
                            child: ShareReceiptSheet(
                              rrn: widget.rrn ?? "",
                              category: bluetoothModel?.category,
                            ));
                      },
                      height: 48,
                      fontSize: 14,
                      fontWeight: FontWeight.w600,
                      textColor: pluginTheme.onPrimary,
                      buttonText: "Share Receipt",
                      buttonColor: pluginTheme.primaryColor,
                    )),
                    const Gap(16),
                    GestureDetector(
                      onTap: () {
                        toRavenPayHome(context);
                      },
                      child: Container(
                          height: 50,
                          width: 58,
                          padding: const EdgeInsets.all(14),
                          decoration: BoxDecoration(
                              color: pluginTheme.primaryColor.withOpacity(0.1),
                              borderRadius: BorderRadius.circular(8)),
                          child: Image.asset(loadAsset("cancel_icon.png"),
                              color: pluginTheme.primaryColor)),
                    )
                  ],
                ),
                const BottomNavSpacer()
              ]),
            ),
            body: SafeArea(
              child: Padding(
                padding:
                    EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
                child: Column(
                  children: [
                    const Gap(24),
                    Align(
                      alignment: Alignment.centerLeft,
                      child: GestureDetector(
                        onTap: () {
                          toRavenPayHome(context);
                        },
                        child:
                            const RoundedItemContainer(asset: "close_icon.png"),
                      ),
                    ),
                    Expanded(
                      child: SingleChildScrollView(
                        child: Stack(
                          children: [
                            Column(
                              children: [
                                Gap(size.height * 0.04),
                                Image.asset(loadAsset("success_icon.png"),
                                    width: size.width * 0.24),
                                const Gap(24),
                                Text("You have successfully paid",
                                    style: subtitle.copyWith(
                                        fontSize: 14,
                                        color: AppColors.ravenPayGrey,
                                        fontWeight: FontWeight.w400)),
                                const Gap(2),
                                RavenPayMoneyWidget(
                                  formatForm: "#,##0.00",
                                  amount: widget.amount.toString(),
                                  fontSize: 28,
                                  color: pluginTheme.isLightTheme
                                      ? AppColors.darkGrey
                                      : Colors.white,
                                ),
                                const Gap(32),
                                Container(
                                    padding: const EdgeInsets.symmetric(
                                        vertical: 16),
                                    width: double.infinity,
                                    decoration: BoxDecoration(
                                        color: pluginTheme.getFGColor,
                                        boxShadow: const [
                                          BoxShadow(
                                              color: Colors.grey,
                                              spreadRadius: -2,
                                              blurRadius: 2)
                                        ],
                                        borderRadius:
                                            BorderRadius.circular(16)),
                                    child: Column(
                                      crossAxisAlignment:
                                          CrossAxisAlignment.start,
                                      children: [
                                        Padding(
                                          padding: const EdgeInsets.symmetric(
                                              horizontal: 16),
                                          child: Row(
                                            children: [
                                              const SuccessCardIcon(),
                                              const Gap(12),
                                              Column(
                                                crossAxisAlignment:
                                                    CrossAxisAlignment.start,
                                                children: [
                                                  Text("Card Pan",
                                                      style: subtitle.copyWith(
                                                          fontWeight:
                                                              FontWeight.w400)),
                                                  const Gap(4),
                                                  Text(
                                                      formatCardPan(
                                                          widget.cardNumber),
                                                      style: subtitle.copyWith(
                                                          color: pluginTheme
                                                                  .isLightTheme
                                                              ? AppColors
                                                                  .ravenPayDark
                                                              : Colors.white))
                                                ],
                                              )
                                            ],
                                          ),
                                        ),
                                        const Gap(4),
                                        Divider(
                                          thickness: 1,
                                          color: pluginTheme.isLightTheme
                                              ? AppColors.lightModeBorder
                                              : AppColors.darkModeBorder,
                                        ),
                                        Padding(
                                            padding: const EdgeInsets.symmetric(
                                                horizontal: 16),
                                            child: Column(
                                              children: [
                                                SuccessItemWidget(
                                                    title: "Terminal SN",
                                                    value:
                                                        widget.terminalSerial),
                                                SuccessItemWidget(
                                                    title: "RRN",
                                                    value: widget.rrn ?? ""),
                                                SuccessItemWidget(
                                                  title: "Card Expiry",
                                                  value: formatExpiry(
                                                      widget.cardExpiry),
                                                ),
                                                SuccessItemWidget(
                                                    title: "Stan",
                                                    showDivider: false,
                                                    value: widget.stan)
                                              ],
                                            ))
                                      ],
                                    )),
                                const Gap(12),
                              ],
                            ),
                            BankBoxCoffetti(
                              key: UniqueKey(),
                            )
                          ],
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            )));
  }
}
